# frozen_string_literal: true

require 'thor'

module Cruncher
  # Handle the application command line parsing
  # and the dispatch to various command objects
  #
  # @api public
  class CLI < Thor
    default_task :scan
    
    # Error raised by this runner
    Error = Class.new(StandardError)

    desc 'version', 'cruncher version'
    def version
      require_relative 'version'
      puts "v#{Cruncher::VERSION}"
    end
    map %w(--version -v) => :version

    desc 'scan URL', 'Command description...'    
    method_option :help, aliases: '-h', type: :boolean,
                         desc: 'Display usage information'
    def scan(url)
      if options[:help]
        invoke :help, ['scan']
      else
        require_relative 'commands/scan'
        Cruncher::Commands::Scan.new(url, options).execute
      end
    end
  end
end
